Title: [216532] trunk
Revision
216532
Author
jlew...@apple.com
Date
2017-05-09 12:15:31 -0700 (Tue, 09 May 2017)

Log Message

Unreviewed, rolling out r216508.

The layout test enabled in this change is failing on Sierra.

Reverted changeset:

"Invalid MediaSource duration value should throw TyperError
instead of InvalidStateError"
https://bugs.webkit.org/show_bug.cgi?id=171653
http://trac.webkit.org/changeset/216508

Modified Paths

Removed Paths

Diff

Modified: trunk/LayoutTests/ChangeLog (216531 => 216532)


--- trunk/LayoutTests/ChangeLog	2017-05-09 18:44:34 UTC (rev 216531)
+++ trunk/LayoutTests/ChangeLog	2017-05-09 19:15:31 UTC (rev 216532)
@@ -1,5 +1,18 @@
 2017-05-09  Matt Lewis  <jlew...@apple.com>
 
+        Unreviewed, rolling out r216508.
+
+        The layout test enabled in this change is failing on Sierra.
+
+        Reverted changeset:
+
+        "Invalid MediaSource duration value should throw TyperError
+        instead of InvalidStateError"
+        https://bugs.webkit.org/show_bug.cgi?id=171653
+        http://trac.webkit.org/changeset/216508
+
+2017-05-09  Matt Lewis  <jlew...@apple.com>
+
         Marked media/element-containing-pip-video-going-into-fullscreen.html as flaky.
         https://bugs.webkit.org/show_bug.cgi?id=162710
 

Modified: trunk/LayoutTests/platform/gtk/TestExpectations (216531 => 216532)


--- trunk/LayoutTests/platform/gtk/TestExpectations	2017-05-09 18:44:34 UTC (rev 216531)
+++ trunk/LayoutTests/platform/gtk/TestExpectations	2017-05-09 19:15:31 UTC (rev 216532)
@@ -250,6 +250,7 @@
 webkit.org/b/167108 imported/w3c/web-platform-tests/media-source/mediasource-config-change-webm-v-bitrate.html [ Failure ]
 webkit.org/b/167108 imported/w3c/web-platform-tests/media-source/mediasource-config-change-webm-v-framerate.html [ Failure ]
 webkit.org/b/167108 imported/w3c/web-platform-tests/media-source/mediasource-config-change-webm-v-framesize.html [ Failure ]
+webkit.org/b/167108 imported/w3c/web-platform-tests/media-source/mediasource-duration-boundaryconditions.html [ Failure ]
 webkit.org/b/167108 imported/w3c/web-platform-tests/media-source/mediasource-duration.html [ Failure ]
 webkit.org/b/167108 imported/w3c/web-platform-tests/media-source/mediasource-endofstream.html [ Failure ]
 webkit.org/b/167108 imported/w3c/web-platform-tests/media-source/mediasource-errors.html [ Failure ]

Deleted: trunk/LayoutTests/platform/gtk/imported/w3c/web-platform-tests/media-source/mediasource-duration-boundaryconditions-expected.txt (216531 => 216532)


--- trunk/LayoutTests/platform/gtk/imported/w3c/web-platform-tests/media-source/mediasource-duration-boundaryconditions-expected.txt	2017-05-09 18:44:34 UTC (rev 216531)
+++ trunk/LayoutTests/platform/gtk/imported/w3c/web-platform-tests/media-source/mediasource-duration-boundaryconditions-expected.txt	2017-05-09 19:15:31 UTC (rev 216532)
@@ -1,15 +0,0 @@
-
-PASS Set duration to 2^31 - 1 
-PASS Set duration to 1 
-FAIL Set duration to Number.MAX_VALUE assert_equals: mediaSource.duration expected 1.7976931348623157e+308 but got Infinity
-PASS Set duration to Number.MIN_VALUE 
-FAIL Set duration to Number.MAX_VALUE - 1 assert_equals: mediaSource.duration expected 1.7976931348623157e+308 but got Infinity
-PASS Set duration to Number.MIN_VALUE - 1 
-FAIL Set duration to Number.POSITIVE_INFINITY assert_equals: mediaElement.duration expected Infinity but got 6.549
-PASS Set duration to Number.NEGATIVE_INFINITY 
-PASS Set duration to lowest value. 
-PASS Set duration to a negative double. 
-PASS Set duration to a positive double. 
-PASS Set duration to zero 
-PASS Set duration to NaN 
-

Modified: trunk/LayoutTests/platform/mac/TestExpectations (216531 => 216532)


--- trunk/LayoutTests/platform/mac/TestExpectations	2017-05-09 18:44:34 UTC (rev 216531)
+++ trunk/LayoutTests/platform/mac/TestExpectations	2017-05-09 19:15:31 UTC (rev 216532)
@@ -1001,6 +1001,7 @@
 webkit.org/b/161725 [ Yosemite+ ] imported/w3c/web-platform-tests/media-source/mediasource-append-buffer.html [ Skip ]
 webkit.org/b/161725 [ Yosemite+ ] imported/w3c/web-platform-tests/media-source/mediasource-appendbuffer-quota-exceeded.html [ Skip ]
 webkit.org/b/161725 [ Yosemite+ ] imported/w3c/web-platform-tests/media-source/mediasource-config-change-mp4-av-framesize.html [ Skip ]
+webkit.org/b/161725 [ Yosemite+ ] imported/w3c/web-platform-tests/media-source/mediasource-duration-boundaryconditions.html [ Skip ]
 webkit.org/b/161725 [ Yosemite+ ] imported/w3c/web-platform-tests/media-source/mediasource-endofstream.html [ Skip ]
 webkit.org/b/161725 [ Yosemite+ ] imported/w3c/web-platform-tests/media-source/mediasource-errors.html [ Skip ]
 webkit.org/b/161725 [ Yosemite+ ] imported/w3c/web-platform-tests/media-source/mediasource-is-type-supported.html [ Skip ]

Deleted: trunk/LayoutTests/platform/mac/imported/w3c/web-platform-tests/media-source/mediasource-duration-boundaryconditions-expected.txt (216531 => 216532)


--- trunk/LayoutTests/platform/mac/imported/w3c/web-platform-tests/media-source/mediasource-duration-boundaryconditions-expected.txt	2017-05-09 18:44:34 UTC (rev 216531)
+++ trunk/LayoutTests/platform/mac/imported/w3c/web-platform-tests/media-source/mediasource-duration-boundaryconditions-expected.txt	2017-05-09 19:15:31 UTC (rev 216532)
@@ -1,17 +0,0 @@
-
-Harness Error (TIMEOUT), message = null
-
-PASS Set duration to 2^31 - 1 
-PASS Set duration to 1 
-FAIL Set duration to Number.MAX_VALUE assert_equals: mediaSource.duration expected 1.7976931348623157e+308 but got Infinity
-PASS Set duration to Number.MIN_VALUE 
-FAIL Set duration to Number.MAX_VALUE - 1 assert_equals: mediaSource.duration expected 1.7976931348623157e+308 but got Infinity
-PASS Set duration to Number.MIN_VALUE - 1 
-PASS Set duration to Number.POSITIVE_INFINITY 
-PASS Set duration to Number.NEGATIVE_INFINITY 
-PASS Set duration to lowest value. 
-PASS Set duration to a negative double. 
-PASS Set duration to a positive double. 
-TIMEOUT Set duration to zero Test timed out
-PASS Set duration to NaN 
-

Modified: trunk/Source/WebCore/ChangeLog (216531 => 216532)


--- trunk/Source/WebCore/ChangeLog	2017-05-09 18:44:34 UTC (rev 216531)
+++ trunk/Source/WebCore/ChangeLog	2017-05-09 19:15:31 UTC (rev 216532)
@@ -1,3 +1,16 @@
+2017-05-09  Matt Lewis  <jlew...@apple.com>
+
+        Unreviewed, rolling out r216508.
+
+        The layout test enabled in this change is failing on Sierra.
+
+        Reverted changeset:
+
+        "Invalid MediaSource duration value should throw TyperError
+        instead of InvalidStateError"
+        https://bugs.webkit.org/show_bug.cgi?id=171653
+        http://trac.webkit.org/changeset/216508
+
 2017-05-09  Michael Catanzaro  <mcatanz...@igalia.com>
 
         Update Chrome and Firefox versions in user agent quirks

Modified: trunk/Source/WebCore/Modules/mediasource/MediaSource.cpp (216531 => 216532)


--- trunk/Source/WebCore/Modules/mediasource/MediaSource.cpp	2017-05-09 18:44:34 UTC (rev 216531)
+++ trunk/Source/WebCore/Modules/mediasource/MediaSource.cpp	2017-05-09 19:15:31 UTC (rev 216532)
@@ -463,18 +463,18 @@
 ExceptionOr<void> MediaSource::setDuration(double duration)
 {
     // 2.1 Attributes - Duration
-    // https://www.w3.org/TR/2016/REC-media-source-20161117/#attributes
+    // https://dvcs.w3.org/hg/html-media/raw-file/tip/media-source/media-source.html#attributes
 
     // On setting, run the following steps:
     // 1. If the value being set is negative or NaN then throw a TypeError exception and abort these steps.
     if (duration < 0.0 || std::isnan(duration))
-        return Exception { TypeError };
+        return Exception { INVALID_ACCESS_ERR };
 
     // 2. If the readyState attribute is not "open" then throw an InvalidStateError exception and abort these steps.
     if (!isOpen())
         return Exception { INVALID_STATE_ERR };
 
     // 3. If the updating attribute equals true on any SourceBuffer in sourceBuffers, then throw an InvalidStateError
     // exception and abort these steps.
     for (auto& sourceBuffer : *m_sourceBuffers) {
         if (sourceBuffer->updating())
@@ -488,7 +488,7 @@
 ExceptionOr<void> MediaSource::setDurationInternal(const MediaTime& duration)
 {
     // 2.4.6 Duration Change
-    // https://www.w3.org/TR/2016/REC-media-source-20161117/#duration-change-algorithm
+    // https://rawgit.com/w3c/media-source/45627646344eea0170dd1cbc5a3d508ca751abb8/media-source-respec.html#duration-change-algorithm
 
     MediaTime newDuration = duration;
 
@@ -463,18 +463,18 @@
 
     // On setting, run the following steps:
-    // 1. If the value being set is negative or NaN then throw a TypeError exception and abort these steps.
+    // 1. If the value being set is negative or NaN then throw an INVALID_ACCESS_ERR exception and abort these steps.
     if (duration < 0.0 || std::isnan(duration))
@@ -463,18 +463,18 @@
 
-    // 2. If the readyState attribute is not "open" then throw an InvalidStateError exception and abort these steps.
+    // 2. If the readyState attribute is not "open" then throw an INVALID_STATE_ERR exception and abort these steps.
     if (!isOpen())
         return Exception { INVALID_STATE_ERR };
@@ -463,18 +463,18 @@
         return Exception { INVALID_STATE_ERR };
 
-    // 3. If the updating attribute equals true on any SourceBuffer in sourceBuffers, then throw an InvalidStateError
+    // 3. If the updating attribute equals true on any SourceBuffer in sourceBuffers, then throw an INVALID_STATE_ERR
     // exception and abort these steps.
     for (auto& sourceBuffer : *m_sourceBuffers) {
_______________________________________________
webkit-changes mailing list
webkit-changes@lists.webkit.org
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to